<?php
// otp-verification.php
header('Content-Type: application/json');

// Retrieve the JSON data from the POST request
$data = json_decode(file_get_contents("php://input"));
$email = $data->email;
$otp = $data->otp;

// Connect to the database
require 'config.php'; // Include your database configuration file
$conn = new mysqli($servername, $username, $password, $dbname);

// Check the connection
if ($conn->connect_error) {
    echo json_encode(["success" => false, "error" => "Database connection failed: " . $conn->connect_error]);
    exit;
}

// Prepare and execute SQL statement to fetch the OTP from the database
$stmt = $conn->prepare("SELECT otp FROM users WHERE email = ?");
if (!$stmt) {
    echo json_encode(["success" => false, "error" => "Failed to prepare statement."]);
    exit;
}

$stmt->bind_param("s", $email);
if ($stmt->execute()) {
    $stmt->bind_result($stored_otp);
    if ($stmt->fetch()) {
        // Convert both received and stored OTPs to strings for comparison
        if ((string)$otp === (string)$stored_otp) {
            // OTP is correct; update OTP to 0 in the database
            $stmt->close();
            $update_stmt = $conn->prepare("UPDATE users SET otp = 0 WHERE email = ?");
            $update_stmt->bind_param("s", $email);
            
            if ($update_stmt->execute()) {
                echo json_encode(["success" => true, "message" => "OTP verified successfully."]);
            } else {
                echo json_encode(["success" => false, "error" => "Failed to update OTP to 0."]);
            }
            $update_stmt->close();
        } else {
            echo json_encode([
                "success" => false,
                "error" => "OTP mismatch.",
                "debug" => [
                    "received_otp" => $otp,
                    "stored_otp" => $stored_otp
                ]
            ]);
        }
    } else {
        echo json_encode(["success" => false, "error" => "No OTP found for the provided email."]);
    }
} else {
    echo json_encode(["success" => false, "error" => "Database query failed."]);
}

// Close the connection
$conn->close();
?>